# initscript.tcl --
#
# The following is the boostrapping script executed in new interpreters 
# under Windows.  It is stored as a resource in the Tcl dll itself.
# It looks on disk in several different directories for a script 
# called "init.tcl" that is compatible with this version of Tcl.  The 
# init.tcl script does all of the real work of initialization.
#
# Copyright (c) 1997 Sun Microsystems, Inc.
#
# SCCS: @(#) initscript.tcl 1.1 97/01/17 10:30:36
#

proc init {} {
    global tcl_library tcl_platform tcl_version tcl_patchLevel env
    rename init {}

    # Replace the arbitrary capitalization of ComSpec, Path, and windir
    # environment variables with ones in all upper case.

    foreach p [array names env] {
	set u [string toupper $p]
	if {$u != $p} {
	    switch -- $u {
		PATH -
		COMSPEC -
		WINDIR {
		    if {![info exists env($u)]} {
			set env($u) $env($p)
		    }
		    unset env($p)
		}
	    }
	}
    }
    if {![info exists env(COMSPEC)]} {
	if {$tcl_platform(os) == "Windows NT"} {
	    set env(COMSPEC) "cmd.exe"
	} else {
	    set env(COMSPEC) "command.com"
	}
    }	

    set dirs {}
    if {[info exists env(TCL_LIBRARY)]} {
	lappend dirs $env(TCL_LIBRARY)
    }
    lappend dirs $tcl_library
    lappend dirs [file join [file dirname [file dirname [info nameofexecutable]]] lib/tcl$tcl_version]
    if [string match {*[ab]*} $tcl_patchLevel] {
	set lib tcl$tcl_patchLevel
    } else {
	set lib tcl$tcl_version
    }
    lappend dirs [file join [file dirname [file dirname [pwd]]] $lib/library]
    lappend dirs [file join [file dirname [pwd]] library]
    foreach i $dirs {
	set tcl_library $i
	if ![catch {uplevel #0 source [list [file join $i init.tcl]]}] {
	    return
	}
    }
    set msg "Can't find a usable init.tcl in the following directories: \n"
    append msg "    $dirs\n"
    append msg "This probably means that Tcl wasn't installed properly.\n"
    error $msg
}

init
